Index: kernel/generic/src/ipc/event.c
===================================================================
--- kernel/generic/src/ipc/event.c	(revision dd8d5a73bdea8475dd6109269d442c9d31c454a6)
+++ kernel/generic/src/ipc/event.c	(revision 1b59023d265904456c850e31b8b942f8cf34a860)
@@ -57,9 +57,9 @@
 		events[i].answerbox = NULL;
 		events[i].counter = 0;
-		events[i].method = 0;
+		events[i].imethod = 0;
 	}
 }
 
-static int event_subscribe(event_type_t evno, sysarg_t method,
+static int event_subscribe(event_type_t evno, sysarg_t imethod,
     answerbox_t *answerbox)
 {
@@ -73,5 +73,5 @@
 	if (events[evno].answerbox == NULL) {
 		events[evno].answerbox = answerbox;
-		events[evno].method = method;
+		events[evno].imethod = imethod;
 		events[evno].counter = 0;
 		res = EOK;
@@ -84,8 +84,8 @@
 }
 
-sysarg_t sys_event_subscribe(sysarg_t evno, sysarg_t method)
+sysarg_t sys_event_subscribe(sysarg_t evno, sysarg_t imethod)
 {
 	return (sysarg_t) event_subscribe((event_type_t) evno, (sysarg_t)
-	    method, &TASK->answerbox);
+	    imethod, &TASK->answerbox);
 }
 
@@ -113,5 +113,5 @@
 			events[i].answerbox = NULL;
 			events[i].counter = 0;
-			events[i].method = 0;
+			events[i].imethod = 0;
 		}
 		spinlock_unlock(&events[i].lock);
@@ -130,5 +130,5 @@
 			call->flags |= IPC_CALL_NOTIF;
 			call->priv = ++events[evno].counter;
-			IPC_SET_METHOD(call->data, events[evno].method);
+			IPC_SET_IMETHOD(call->data, events[evno].imethod);
 			IPC_SET_ARG1(call->data, a1);
 			IPC_SET_ARG2(call->data, a2);
Index: kernel/generic/src/ipc/ipc.c
===================================================================
--- kernel/generic/src/ipc/ipc.c	(revision dd8d5a73bdea8475dd6109269d442c9d31c454a6)
+++ kernel/generic/src/ipc/ipc.c	(revision 1b59023d265904456c850e31b8b942f8cf34a860)
@@ -367,5 +367,5 @@
 		
 		call_t *call = ipc_call_alloc(0);
-		IPC_SET_METHOD(call->data, IPC_M_PHONE_HUNGUP);
+		IPC_SET_IMETHOD(call->data, IPC_M_PHONE_HUNGUP);
 		call->flags |= IPC_CALL_DISCARD_ANSWER;
 		_ipc_call(phone, box, call);
@@ -547,5 +547,5 @@
 			 * disconnected.
 			 */
-			IPC_SET_METHOD(call->data, IPC_M_PHONE_HUNGUP);
+			IPC_SET_IMETHOD(call->data, IPC_M_PHONE_HUNGUP);
 			call->flags |= IPC_CALL_DISCARD_ANSWER;
 			_ipc_call(phone, box, call);
@@ -741,5 +741,5 @@
 		    " A4:%" PRIun " A5:%" PRIun " Flags:%x\n", call,
 		    call->sender->taskid,
-		    IPC_GET_METHOD(call->data), IPC_GET_ARG1(call->data),
+		    IPC_GET_IMETHOD(call->data), IPC_GET_ARG1(call->data),
 		    IPC_GET_ARG2(call->data), IPC_GET_ARG3(call->data),
 		    IPC_GET_ARG4(call->data), IPC_GET_ARG5(call->data),
@@ -757,5 +757,5 @@
 		    " A4:%" PRIun " A5:%" PRIun " Flags:%x\n", call,
 		    call->sender->taskid,
-		    IPC_GET_METHOD(call->data), IPC_GET_ARG1(call->data),
+		    IPC_GET_IMETHOD(call->data), IPC_GET_ARG1(call->data),
 		    IPC_GET_ARG2(call->data), IPC_GET_ARG3(call->data),
 		    IPC_GET_ARG4(call->data), IPC_GET_ARG5(call->data),
@@ -771,5 +771,5 @@
 		printf("Callid:%p M:%" PRIun " A1:%" PRIun " A2:%" PRIun
 		    " A3:%" PRIun " A4:%" PRIun " A5:%" PRIun " Flags:%x\n",
-		    call, IPC_GET_METHOD(call->data), IPC_GET_ARG1(call->data),
+		    call, IPC_GET_IMETHOD(call->data), IPC_GET_ARG1(call->data),
 		    IPC_GET_ARG2(call->data), IPC_GET_ARG3(call->data),
 		    IPC_GET_ARG4(call->data), IPC_GET_ARG5(call->data),
Index: kernel/generic/src/ipc/kbox.c
===================================================================
--- kernel/generic/src/ipc/kbox.c	(revision dd8d5a73bdea8475dd6109269d442c9d31c454a6)
+++ kernel/generic/src/ipc/kbox.c	(revision 1b59023d265904456c850e31b8b942f8cf34a860)
@@ -167,5 +167,5 @@
 			continue;  /* Try again. */
 		
-		switch (IPC_GET_METHOD(call->data)) {
+		switch (IPC_GET_IMETHOD(call->data)) {
 		
 		case IPC_M_DEBUG_ALL:
Index: kernel/generic/src/ipc/sysipc.c
===================================================================
--- kernel/generic/src/ipc/sysipc.c	(revision dd8d5a73bdea8475dd6109269d442c9d31c454a6)
+++ kernel/generic/src/ipc/sysipc.c	(revision 1b59023d265904456c850e31b8b942f8cf34a860)
@@ -78,14 +78,15 @@
 }
 
-/** Decide if the method is a system method.
- *
- * @param method Method to be decided.
- *
- * @return true if the method is a system method.
- *
- */
-static inline bool method_is_system(sysarg_t method)
-{
-	if (method <= IPC_M_LAST_SYSTEM)
+/** Decide if the interface and method is a system method.
+ *
+ * @param imethod Interface and method to be decided.
+ *
+ * @return True if the interface and method is a system
+ *         interface and method.
+ *
+ */
+static inline bool method_is_system(sysarg_t imethod)
+{
+	if (imethod <= IPC_M_LAST_SYSTEM)
 		return true;
 	
@@ -93,17 +94,17 @@
 }
 
-/** Decide if the message with this method is forwardable.
- *
- * - some system messages may be forwarded, for some of them
- *   it is useless
- *
- * @param method Method to be decided.
- *
- * @return true if the method is forwardable.
- *
- */
-static inline bool method_is_forwardable(sysarg_t method)
-{
-	switch (method) {
+/** Decide if the message with this interface and method is forwardable.
+ *
+ * Some system messages may be forwarded, for some of them
+ * it is useless.
+ *
+ * @param imethod Interface and method to be decided.
+ *
+ * @return True if the interface and method is forwardable.
+ *
+ */
+static inline bool method_is_forwardable(sysarg_t imethod)
+{
+	switch (imethod) {
 	case IPC_M_CONNECTION_CLONE:
 	case IPC_M_CONNECT_ME:
@@ -116,16 +117,16 @@
 }
 
-/** Decide if the message with this method is immutable on forward.
- *
- * - some system messages may be forwarded but their content cannot be altered
- *
- * @param method Method to be decided.
- *
- * @return true if the method is immutable on forward.
- *
- */
-static inline bool method_is_immutable(sysarg_t method)
-{
-	switch (method) {
+/** Decide if the message with this interface and method is immutable on forward.
+ *
+ * Some system messages may be forwarded but their content cannot be altered.
+ *
+ * @param imethod Interface and method to be decided.
+ *
+ * @return True if the interface and method is immutable on forward.
+ *
+ */
+static inline bool method_is_immutable(sysarg_t imethod)
+{
+	switch (imethod) {
 	case IPC_M_SHARE_OUT:
 	case IPC_M_SHARE_IN:
@@ -153,5 +154,5 @@
 static inline bool answer_need_old(call_t *call)
 {
-	switch (IPC_GET_METHOD(call->data)) {
+	switch (IPC_GET_IMETHOD(call->data)) {
 	case IPC_M_CONNECTION_CLONE:
 	case IPC_M_CONNECT_ME:
@@ -197,5 +198,5 @@
 		return 0;
 	
-	if (IPC_GET_METHOD(*olddata) == IPC_M_CONNECTION_CLONE) {
+	if (IPC_GET_IMETHOD(*olddata) == IPC_M_CONNECTION_CLONE) {
 		int phoneid = IPC_GET_ARG1(*olddata);
 		phone_t *phone = &TASK->phones[phoneid];
@@ -219,5 +220,5 @@
 			mutex_unlock(&phone->lock);
 		}
-	} else if (IPC_GET_METHOD(*olddata) == IPC_M_CONNECT_ME) {
+	} else if (IPC_GET_IMETHOD(*olddata) == IPC_M_CONNECT_ME) {
 		phone_t *phone = (phone_t *) IPC_GET_ARG5(*olddata);
 		
@@ -238,5 +239,5 @@
 			mutex_unlock(&phone->lock);
 		}
-	} else if (IPC_GET_METHOD(*olddata) == IPC_M_CONNECT_TO_ME) {
+	} else if (IPC_GET_IMETHOD(*olddata) == IPC_M_CONNECT_TO_ME) {
 		int phoneid = IPC_GET_ARG5(*olddata);
 		
@@ -251,5 +252,5 @@
 			    (sysarg_t) &TASK->phones[phoneid]);
 		}
-	} else if (IPC_GET_METHOD(*olddata) == IPC_M_CONNECT_ME_TO) {
+	} else if (IPC_GET_IMETHOD(*olddata) == IPC_M_CONNECT_ME_TO) {
 		/* If the users accepted call, connect */
 		if (IPC_GET_RETVAL(answer->data) == EOK) {
@@ -257,5 +258,5 @@
 			    &TASK->answerbox);
 		}
-	} else if (IPC_GET_METHOD(*olddata) == IPC_M_SHARE_OUT) {
+	} else if (IPC_GET_IMETHOD(*olddata) == IPC_M_SHARE_OUT) {
 		if (!IPC_GET_RETVAL(answer->data)) {
 			/* Accepted, handle as_area receipt */
@@ -271,5 +272,5 @@
 			return rc;
 		}
-	} else if (IPC_GET_METHOD(*olddata) == IPC_M_SHARE_IN) {
+	} else if (IPC_GET_IMETHOD(*olddata) == IPC_M_SHARE_IN) {
 		if (!IPC_GET_RETVAL(answer->data)) { 
 			irq_spinlock_lock(&answer->sender->lock, true);
@@ -282,5 +283,5 @@
 			IPC_SET_RETVAL(answer->data, rc);
 		}
-	} else if (IPC_GET_METHOD(*olddata) == IPC_M_DATA_READ) {
+	} else if (IPC_GET_IMETHOD(*olddata) == IPC_M_DATA_READ) {
 		ASSERT(!answer->buffer);
 		if (!IPC_GET_RETVAL(answer->data)) {
@@ -311,5 +312,5 @@
 			}
 		}
-	} else if (IPC_GET_METHOD(*olddata) == IPC_M_DATA_WRITE) {
+	} else if (IPC_GET_IMETHOD(*olddata) == IPC_M_DATA_WRITE) {
 		ASSERT(answer->buffer);
 		if (!IPC_GET_RETVAL(answer->data)) {
@@ -364,5 +365,5 @@
 static int request_preprocess(call_t *call, phone_t *phone)
 {
-	switch (IPC_GET_METHOD(call->data)) {
+	switch (IPC_GET_IMETHOD(call->data)) {
 	case IPC_M_CONNECTION_CLONE: {
 		phone_t *cloned_phone;
@@ -504,5 +505,5 @@
 static int process_request(answerbox_t *box, call_t *call)
 {
-	if (IPC_GET_METHOD(call->data) == IPC_M_CONNECT_TO_ME) {
+	if (IPC_GET_IMETHOD(call->data) == IPC_M_CONNECT_TO_ME) {
 		int phoneid = phone_alloc(TASK);
 		if (phoneid < 0) { /* Failed to allocate phone */
@@ -515,5 +516,5 @@
 	}
 	
-	switch (IPC_GET_METHOD(call->data)) {
+	switch (IPC_GET_IMETHOD(call->data)) {
 	case IPC_M_DEBUG_ALL:
 		return -1;
@@ -531,9 +532,9 @@
  *
  * @param phoneid Phone handle for the call.
- * @param method  Method of the call.
+ * @param imethod Interface and method of the call.
  * @param arg1    Service-defined payload argument.
  * @param arg2    Service-defined payload argument.
  * @param arg3    Service-defined payload argument.
- * @param data    Address of userspace structure where the reply call will
+ * @param data    Address of user-space structure where the reply call will
  *                be stored.
  *
@@ -542,5 +543,5 @@
  *
  */
-sysarg_t sys_ipc_call_sync_fast(sysarg_t phoneid, sysarg_t method,
+sysarg_t sys_ipc_call_sync_fast(sysarg_t phoneid, sysarg_t imethod,
     sysarg_t arg1, sysarg_t arg2, sysarg_t arg3, ipc_data_t *data)
 {
@@ -548,7 +549,7 @@
 	if (phone_get(phoneid, &phone) != EOK)
 		return ENOENT;
-
+	
 	call_t *call = ipc_call_alloc(0);
-	IPC_SET_METHOD(call->data, method);
+	IPC_SET_IMETHOD(call->data, imethod);
 	IPC_SET_ARG1(call->data, arg1);
 	IPC_SET_ARG2(call->data, arg2);
@@ -580,5 +581,4 @@
 		
 		process_answer(call);
-		
 	} else
 		IPC_SET_RETVAL(call->data, res);
@@ -594,13 +594,13 @@
 /** Make a synchronous IPC call allowing to transmit the entire payload.
  *
- * @param phoneid  Phone handle for the call.
- * @param question Userspace address of call data with the request.
- * @param reply    Userspace address of call data where to store the
- *                 answer.
+ * @param phoneid Phone handle for the call.
+ * @param request User-space address of call data with the request.
+ * @param reply   User-space address of call data where to store the
+ *                answer.
  *
  * @return Zero on success or an error code.
  *
  */
-sysarg_t sys_ipc_call_sync_slow(sysarg_t phoneid, ipc_data_t *question,
+sysarg_t sys_ipc_call_sync_slow(sysarg_t phoneid, ipc_data_t *request,
     ipc_data_t *reply)
 {
@@ -608,7 +608,7 @@
 	if (phone_get(phoneid, &phone) != EOK)
 		return ENOENT;
-
+	
 	call_t *call = ipc_call_alloc(0);
-	int rc = copy_from_uspace(&call->data.args, &question->args,
+	int rc = copy_from_uspace(&call->data.args, &request->args,
 	    sizeof(call->data.args));
 	if (rc != 0) {
@@ -648,5 +648,6 @@
  * made over a phone.
  *
- * @param phone Phone to check the limit against. 
+ * @param phone Phone to check the limit against.
+ *
  * @return 0 if limit not reached or -1 if limit exceeded.
  *
@@ -666,5 +667,5 @@
  *
  * @param phoneid Phone handle for the call.
- * @param method  Method of the call.
+ * @param imethod Interface and method of the call.
  * @param arg1    Service-defined payload argument.
  * @param arg2    Service-defined payload argument.
@@ -678,5 +679,5 @@
  *
  */
-sysarg_t sys_ipc_call_async_fast(sysarg_t phoneid, sysarg_t method,
+sysarg_t sys_ipc_call_async_fast(sysarg_t phoneid, sysarg_t imethod,
     sysarg_t arg1, sysarg_t arg2, sysarg_t arg3, sysarg_t arg4)
 {
@@ -684,10 +685,10 @@
 	if (phone_get(phoneid, &phone) != EOK)
 		return IPC_CALLRET_FATAL;
-
+	
 	if (check_call_limit(phone))
 		return IPC_CALLRET_TEMPORARY;
 	
 	call_t *call = ipc_call_alloc(0);
-	IPC_SET_METHOD(call->data, method);
+	IPC_SET_IMETHOD(call->data, imethod);
 	IPC_SET_ARG1(call->data, arg1);
 	IPC_SET_ARG2(call->data, arg2);
@@ -752,5 +753,5 @@
  * @param callid  Hash of the call to forward.
  * @param phoneid Phone handle to use for forwarding.
- * @param method  New method to use for the forwarded call.
+ * @param imethod New interface and method to use for the forwarded call.
  * @param arg1    New value of the first argument for the forwarded call.
  * @param arg2    New value of the second argument for the forwarded call.
@@ -769,5 +770,5 @@
  */
 static sysarg_t sys_ipc_forward_common(sysarg_t callid, sysarg_t phoneid,
-    sysarg_t method, sysarg_t arg1, sysarg_t arg2, sysarg_t arg3,
+    sysarg_t imethod, sysarg_t arg1, sysarg_t arg2, sysarg_t arg3,
     sysarg_t arg4, sysarg_t arg5, unsigned int mode, bool slow)
 {
@@ -785,5 +786,5 @@
 	}
 	
-	if (!method_is_forwardable(IPC_GET_METHOD(call->data))) {
+	if (!method_is_forwardable(IPC_GET_IMETHOD(call->data))) {
 		IPC_SET_RETVAL(call->data, EFORWARD);
 		ipc_answer(&TASK->answerbox, call);
@@ -792,15 +793,15 @@
 	
 	/*
-	 * Userspace is not allowed to change method of system methods on
-	 * forward, allow changing ARG1, ARG2, ARG3 and ARG4 by means of method,
-	 * arg1, arg2 and arg3.
-	 * If the method is immutable, don't change anything.
+	 * Userspace is not allowed to change interface and method of system
+	 * methods on forward, allow changing ARG1, ARG2, ARG3 and ARG4 by
+	 * means of method, arg1, arg2 and arg3.
+	 * If the interface and method is immutable, don't change anything.
 	 */
-	if (!method_is_immutable(IPC_GET_METHOD(call->data))) {
-		if (method_is_system(IPC_GET_METHOD(call->data))) {
-			if (IPC_GET_METHOD(call->data) == IPC_M_CONNECT_TO_ME)
+	if (!method_is_immutable(IPC_GET_IMETHOD(call->data))) {
+		if (method_is_system(IPC_GET_IMETHOD(call->data))) {
+			if (IPC_GET_IMETHOD(call->data) == IPC_M_CONNECT_TO_ME)
 				phone_dealloc(IPC_GET_ARG5(call->data));
 			
-			IPC_SET_ARG1(call->data, method);
+			IPC_SET_ARG1(call->data, imethod);
 			IPC_SET_ARG2(call->data, arg1);
 			IPC_SET_ARG3(call->data, arg2);
@@ -814,5 +815,5 @@
 			}
 		} else {
-			IPC_SET_METHOD(call->data, method);
+			IPC_SET_IMETHOD(call->data, imethod);
 			IPC_SET_ARG1(call->data, arg1);
 			IPC_SET_ARG2(call->data, arg2);
@@ -830,14 +831,14 @@
 /** Forward a received call to another destination - fast version.
  *
- * In case the original method is a system method, ARG1, ARG2 and ARG3 are
- * overwritten in the forwarded message with the new method and the new
- * arg1 and arg2, respectively. Otherwise the METHOD, ARG1 and ARG2 are
- * rewritten with the new method, arg1 and arg2, respectively. Also note there
- * is a set of immutable methods, for which the new method and arguments are not
- * set and these values are ignored.
+ * In case the original interface and method is a system method, ARG1, ARG2
+ * and ARG3 are overwritten in the forwarded message with the new method and
+ * the new arg1 and arg2, respectively. Otherwise the IMETHOD, ARG1 and ARG2
+ * are rewritten with the new interface and method, arg1 and arg2, respectively.
+ * Also note there is a set of immutable methods, for which the new method and
+ * arguments are not set and these values are ignored.
  *
  * @param callid  Hash of the call to forward.
  * @param phoneid Phone handle to use for forwarding.
- * @param method  New method to use for the forwarded call.
+ * @param imethod New interface and method to use for the forwarded call.
  * @param arg1    New value of the first argument for the forwarded call.
  * @param arg2    New value of the second argument for the forwarded call.
@@ -848,7 +849,7 @@
  */
 sysarg_t sys_ipc_forward_fast(sysarg_t callid, sysarg_t phoneid,
-    sysarg_t method, sysarg_t arg1, sysarg_t arg2, unsigned int mode)
-{
-	return sys_ipc_forward_common(callid, phoneid, method, arg1, arg2, 0, 0,
+    sysarg_t imethod, sysarg_t arg1, sysarg_t arg2, unsigned int mode)
+{
+	return sys_ipc_forward_common(callid, phoneid, imethod, arg1, arg2, 0, 0,
 	    0, mode, false); 
 }
@@ -857,9 +858,9 @@
  *
  * This function is the slow verision of the sys_ipc_forward_fast interface.
- * It can copy all five new arguments and the new method from the userspace.
- * It naturally extends the functionality of the fast version. For system
- * methods, it additionally stores the new value of arg3 to ARG4. For non-system
- * methods, it additionally stores the new value of arg3, arg4 and arg5,
- * respectively, to ARG3, ARG4 and ARG5, respectively.
+ * It can copy all five new arguments and the new interface and method from
+ * the userspace. It naturally extends the functionality of the fast version.
+ * For system methods, it additionally stores the new value of arg3 to ARG4.
+ * For non-system methods, it additionally stores the new value of arg3, arg4
+ * and arg5, respectively, to ARG3, ARG4 and ARG5, respectively.
  *
  * @param callid  Hash of the call to forward.
@@ -881,5 +882,5 @@
 	
 	return sys_ipc_forward_common(callid, phoneid,
-	    IPC_GET_METHOD(newdata), IPC_GET_ARG1(newdata),
+	    IPC_GET_IMETHOD(newdata), IPC_GET_ARG1(newdata),
 	    IPC_GET_ARG2(newdata), IPC_GET_ARG3(newdata),
 	    IPC_GET_ARG4(newdata), IPC_GET_ARG5(newdata), mode, true); 
@@ -1094,13 +1095,13 @@
 /** Connect an IRQ handler to a task.
  *
- * @param inr    IRQ number.
- * @param devno  Device number.
- * @param method Method to be associated with the notification.
- * @param ucode  Uspace pointer to the top-half pseudocode.
+ * @param inr     IRQ number.
+ * @param devno   Device number.
+ * @param imethod Interface and method to be associated with the notification.
+ * @param ucode   Uspace pointer to the top-half pseudocode.
  *
  * @return EPERM or a return code returned by ipc_irq_register().
  *
  */
-sysarg_t sys_ipc_register_irq(inr_t inr, devno_t devno, sysarg_t method,
+sysarg_t sys_ipc_register_irq(inr_t inr, devno_t devno, sysarg_t imethod,
     irq_code_t *ucode)
 {
@@ -1108,5 +1109,5 @@
 		return EPERM;
 	
-	return ipc_irq_register(&TASK->answerbox, inr, devno, method, ucode);
+	return ipc_irq_register(&TASK->answerbox, inr, devno, imethod, ucode);
 }
 

Index: kernel/generic/src/ipc/irq.c
===================================================================
--- kernel/generic/src/ipc/irq.c	(revision dd8d5a73bdea8475dd6109269d442c9d31c454a6)
+++ kernel/generic/src/ipc/irq.c	(revision 1b59023d265904456c850e31b8b942f8cf34a860)
@@ -42,5 +42,6 @@
  *
  * The structure of a notification message is as follows:
  * - METHOD: method as registered by the SYS_IPC_REGISTER_IRQ syscall
  * - ARG1: payload modified by a 'top-half' handler
  * - ARG2: payload modified by a 'top-half' handler
@@ -49,5 +50,5 @@
  * - ARG5: payload modified by a 'top-half' handler
  * - in_phone_hash: interrupt counter (may be needed to assure correct order
- *         in multithreaded drivers)
+ *                  in multithreaded drivers)
  *
  * Note on synchronization for ipc_irq_register(), ipc_irq_unregister(),
@@ -130,9 +131,10 @@
 /** Register an answerbox as a receiving end for IRQ notifications.
  *
  * @param box    Receiving answerbox.
  * @param inr    IRQ number.
  * @param devno  Device number.
  * @param method Method to be associated with the notification.
  * @param ucode  Uspace pointer to top-half pseudocode.
  *
  * @return EBADMEM, ENOENT or EEXISTS on failure or 0 on success.
@@ -140,5 +142,5 @@
  */
 int ipc_irq_register(answerbox_t *box, inr_t inr, devno_t devno,
-    sysarg_t method, irq_code_t *ucode)
+    sysarg_t imethod, irq_code_t *ucode)
 {
 	sysarg_t key[] = {
@@ -167,5 +169,5 @@
 	irq->notif_cfg.notify = true;
 	irq->notif_cfg.answerbox = box;
-	irq->notif_cfg.method = method;
+	irq->notif_cfg.imethod = imethod;
 	irq->notif_cfg.code = code;
 	irq->notif_cfg.counter = 0;
@@ -444,5 +446,5 @@
 		
 		/* Set up args */
-		IPC_SET_METHOD(call->data, irq->notif_cfg.method);
+		IPC_SET_IMETHOD(call->data, irq->notif_cfg.imethod);
 		IPC_SET_ARG1(call->data, irq->notif_cfg.scratch[1]);
 		IPC_SET_ARG2(call->data, irq->notif_cfg.scratch[2]);
@@ -481,5 +483,5 @@
 		call->priv = ++irq->notif_cfg.counter;
 		
-		IPC_SET_METHOD(call->data, irq->notif_cfg.method);
+		IPC_SET_IMETHOD(call->data, irq->notif_cfg.imethod);
 		IPC_SET_ARG1(call->data, a1);
 		IPC_SET_ARG2(call->data, a2);
@@ -42,5 +42,6 @@
  *
  * The structure of a notification message is as follows:
- * - METHOD: method as registered by the SYS_IPC_REGISTER_IRQ syscall
+ * - IMETHOD: interface and method as registered by the SYS_IPC_REGISTER_IRQ
+ *            syscall
  * - ARG1: payload modified by a 'top-half' handler
  * - ARG2: payload modified by a 'top-half' handler
@@ -130,9 +131,10 @@
 /** Register an answerbox as a receiving end for IRQ notifications.
  *
- * @param box    Receiving answerbox.
- * @param inr    IRQ number.
- * @param devno  Device number.
- * @param method Method to be associated with the notification.
- * @param ucode  Uspace pointer to top-half pseudocode.
+ * @param box     Receiving answerbox.
+ * @param inr     IRQ number.
+ * @param devno   Device number.
+ * @param imethod Interface and method to be associated
+ *                with the notification.
+ * @param ucode   Uspace pointer to top-half pseudocode.
  *
  * @return EBADMEM, ENOENT or EEXISTS on failure or 0 on success.